summaryrefslogtreecommitdiff
path: root/plugins/taglist
diff options
context:
space:
mode:
authorPerberos <[email protected]>2011-11-07 19:52:18 -0300
committerPerberos <[email protected]>2011-11-07 19:52:18 -0300
commit5ded9cba8563f336939400303d6a841d5089b107 (patch)
treec5676588cff26ba37e12369fe4de24b54e9f6682 /plugins/taglist
parentf00b3a11a199f9f85a4d46a600f9d14179b37dbf (diff)
downloadpluma-5ded9cba8563f336939400303d6a841d5089b107.tar.bz2
pluma-5ded9cba8563f336939400303d6a841d5089b107.tar.xz
renaming from gedit to pluma
Diffstat (limited to 'plugins/taglist')
-rwxr-xr-xplugins/taglist/HTML.tags.xml.in2
-rwxr-xr-xplugins/taglist/Latex.tags.xml.in2
-rwxr-xr-xplugins/taglist/Makefile.am26
-rwxr-xr-xplugins/taglist/XSLT.tags.xml.in4
-rwxr-xr-xplugins/taglist/XUL.tags.xml.in2
-rwxr-xr-xplugins/taglist/gedit-taglist-plugin-panel.h89
-rwxr-xr-xplugins/taglist/gedit-taglist-plugin.h85
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin-panel.c (renamed from plugins/taglist/gedit-taglist-plugin-panel.c)148
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin-panel.h89
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin-parser.c (renamed from plugins/taglist/gedit-taglist-plugin-parser.c)74
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin-parser.h (renamed from plugins/taglist/gedit-taglist-plugin-parser.h)14
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin.c (renamed from plugins/taglist/gedit-taglist-plugin.c)86
-rwxr-xr-xplugins/taglist/pluma-taglist-plugin.h85
-rwxr-xr-xplugins/taglist/taglist.pluma-plugin.desktop.in (renamed from plugins/taglist/taglist.gedit-plugin.desktop.in)4
14 files changed, 355 insertions, 355 deletions
diff --git a/plugins/taglist/HTML.tags.xml.in b/plugins/taglist/HTML.tags.xml.in
index 116cc247..5eedb254 100755
--- a/plugins/taglist/HTML.tags.xml.in
+++ b/plugins/taglist/HTML.tags.xml.in
@@ -1,5 +1,5 @@
<?xml version="1.0" encoding="UTF-8"?>
-<TagList xmlns="http://gedit.sourceforge.net/some-location">
+<TagList xmlns="http://pluma.sourceforge.net/some-location">
<TagGroup _name="XHTML 1.0 - Tags" sort="true">
<Tag _name="Abbreviated form">
diff --git a/plugins/taglist/Latex.tags.xml.in b/plugins/taglist/Latex.tags.xml.in
index 5ac71c0d..78242fe3 100755
--- a/plugins/taglist/Latex.tags.xml.in
+++ b/plugins/taglist/Latex.tags.xml.in
@@ -1,5 +1,5 @@
<?xml version="1.0" encoding="UTF-8"?>
-<TagList xmlns="http://gedit.sourceforge.net/some-location">
+<TagList xmlns="http://pluma.sourceforge.net/some-location">
<TagGroup _name="Latex - Tags" sort="true">
<Tag _name="Bibliography (cite)">
<Begin>\cite{ </Begin>
diff --git a/plugins/taglist/Makefile.am b/plugins/taglist/Makefile.am
index b04f4584..dd3306f0 100755
--- a/plugins/taglist/Makefile.am
+++ b/plugins/taglist/Makefile.am
@@ -1,7 +1,7 @@
# Tag list plugin
-plugindir = $(GEDIT_PLUGINS_LIBS_DIR)
+plugindir = $(PLUMA_PLUGINS_LIBS_DIR)
-taglistdir = $(GEDIT_PLUGINS_DATA_DIR)/taglist
+taglistdir = $(PLUMA_PLUGINS_DATA_DIR)/taglist
taglist_in_files = \
HTML.tags.xml.in \
@@ -13,26 +13,26 @@ taglist_DATA = $(taglist_in_files:.tags.xml.in=.tags.gz)
INCLUDES = \
-I$(top_srcdir) \
- $(GEDIT_CFLAGS) \
+ $(PLUMA_CFLAGS) \
$(WARN_CFLAGS) \
$(DISABLE_DEPRECATED_CFLAGS)
plugin_LTLIBRARIES = libtaglist.la
libtaglist_la_SOURCES = \
- gedit-taglist-plugin-parser.c \
- gedit-taglist-plugin-parser.h \
- gedit-taglist-plugin-panel.c \
- gedit-taglist-plugin-panel.h \
- gedit-taglist-plugin.c \
- gedit-taglist-plugin.h
+ pluma-taglist-plugin-parser.c \
+ pluma-taglist-plugin-parser.h \
+ pluma-taglist-plugin-panel.c \
+ pluma-taglist-plugin-panel.h \
+ pluma-taglist-plugin.c \
+ pluma-taglist-plugin.h
libtaglist_la_LDFLAGS = $(PLUGIN_LIBTOOL_FLAGS)
-libtaglist_la_LIBADD = $(GEDIT_LIBS)
+libtaglist_la_LIBADD = $(PLUMA_LIBS)
-plugin_in_files = taglist.gedit-plugin.desktop.in
+plugin_in_files = taglist.pluma-plugin.desktop.in
-%.gedit-plugin: %.gedit-plugin.desktop.in $(INTLTOOL_MERGE) $(wildcard $(top_srcdir)/po/*po)
+%.pluma-plugin: %.pluma-plugin.desktop.in $(INTLTOOL_MERGE) $(wildcard $(top_srcdir)/po/*po)
$(INTLTOOL_MERGE) $(top_srcdir)/po $< $@ -d -u -c $(top_builddir)/po/.intltool-merge-cache
GZIP_ENV = -9
@@ -41,7 +41,7 @@ GZIP_ENV = -9
LC_ALL=C $(INTLTOOL_MERGE) $(top_srcdir)/po $< $(@:.gz=) -x -u -c $(top_builddir)/po/.intltool-merge-cache
GZIP=$(GZIP_ENV) gzip -f $(@:.gz=)
-plugin_DATA = $(plugin_in_files:.gedit-plugin.desktop.in=.gedit-plugin)
+plugin_DATA = $(plugin_in_files:.pluma-plugin.desktop.in=.pluma-plugin)
EXTRA_DIST = \
$(taglist_in_files) $(taglist_DATA) \
diff --git a/plugins/taglist/XSLT.tags.xml.in b/plugins/taglist/XSLT.tags.xml.in
index f9591a25..e625f6ca 100755
--- a/plugins/taglist/XSLT.tags.xml.in
+++ b/plugins/taglist/XSLT.tags.xml.in
@@ -1,9 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
- XSLT Tags for gedit
+ XSLT Tags for pluma
Jens Askengren <[email protected]>
-->
-<TagList xmlns="http://gedit.sourceforge.net/some-location">
+<TagList xmlns="http://pluma.sourceforge.net/some-location">
<TagGroup _name="XSLT - Elements" sort="true">
<Tag name="apply-imports">
<Begin>&lt;xsl:apply-imports&gt;</Begin>
diff --git a/plugins/taglist/XUL.tags.xml.in b/plugins/taglist/XUL.tags.xml.in
index fc4c26a7..3d5d3c8c 100755
--- a/plugins/taglist/XUL.tags.xml.in
+++ b/plugins/taglist/XUL.tags.xml.in
@@ -1,5 +1,5 @@
<?xml version="1.0" encoding="UTF-8"?>
-<TagList xmlns="http://gedit.sourceforge.net/some-location">
+<TagList xmlns="http://pluma.sourceforge.net/some-location">
<TagGroup _name="XUL - Tags" sort="true">
<Tag name="action">
diff --git a/plugins/taglist/gedit-taglist-plugin-panel.h b/plugins/taglist/gedit-taglist-plugin-panel.h
deleted file mode 100755
index 3f8e82d0..00000000
--- a/plugins/taglist/gedit-taglist-plugin-panel.h
+++ /dev/null
@@ -1,89 +0,0 @@
-/*
- * gedit-taglist-plugin-panel.h
- * This file is part of gedit
- *
- * Copyright (C) 2005 - Paolo Maggi
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
- */
-
-#ifndef __GEDIT_TAGLIST_PLUGIN_PANEL_H__
-#define __GEDIT_TAGLIST_PLUGIN_PANEL_H__
-
-#include <gtk/gtk.h>
-
-#include <gedit/gedit-window.h>
-
-G_BEGIN_DECLS
-
-/*
- * Type checking and casting macros
- */
-#define GEDIT_TYPE_TAGLIST_PLUGIN_PANEL (gedit_taglist_plugin_panel_get_type())
-#define GEDIT_TAGLIST_PLUGIN_PANEL(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL, GeditTaglistPluginPanel))
-#define GEDIT_TAGLIST_PLUGIN_PANEL_CONST(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL, GeditTaglistPluginPanel const))
-#define GEDIT_TAGLIST_PLUGIN_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL, GeditTaglistPluginPanelClass))
-#define GEDIT_IS_TAGLIST_PLUGIN_PANEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL))
-#define GEDIT_IS_TAGLIST_PLUGIN_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL))
-#define GEDIT_TAGLIST_PLUGIN_PANEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), GEDIT_TYPE_TAGLIST_PLUGIN_PANEL, GeditTaglistPluginPanelClass))
-
-/* Private structure type */
-typedef struct _GeditTaglistPluginPanelPrivate GeditTaglistPluginPanelPrivate;
-
-/*
- * Main object structure
- */
-typedef struct _GeditTaglistPluginPanel GeditTaglistPluginPanel;
-
-struct _GeditTaglistPluginPanel
-{
- GtkVBox vbox;
-
- /*< private > */
- GeditTaglistPluginPanelPrivate *priv;
-};
-
-/*
- * Class definition
- */
-typedef struct _GeditTaglistPluginPanelClass GeditTaglistPluginPanelClass;
-
-struct _GeditTaglistPluginPanelClass
-{
- GtkVBoxClass parent_class;
-};
-
-/*
- * Public methods
- */
-GType gedit_taglist_plugin_panel_register_type (GTypeModule *module);
-
-GType gedit_taglist_plugin_panel_get_type (void) G_GNUC_CONST;
-
-GtkWidget *gedit_taglist_plugin_panel_new (GeditWindow *window,
- const gchar *data_dir);
-
-G_END_DECLS
-
-#endif /* __GEDIT_TAGLIST_PLUGIN_PANEL_H__ */
diff --git a/plugins/taglist/gedit-taglist-plugin.h b/plugins/taglist/gedit-taglist-plugin.h
deleted file mode 100755
index d0444e76..00000000
--- a/plugins/taglist/gedit-taglist-plugin.h
+++ /dev/null
@@ -1,85 +0,0 @@
-/*
- * gedit-taglist-plugin.h
- *
- * Copyright (C) 2002-2005 - Paolo Maggi
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
-
-/*
- * Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
- */
-
-#ifndef __GEDIT_TAGLIST_PLUGIN_H__
-#define __GEDIT_TAGLIST_PLUGIN_H__
-
-#include <glib.h>
-#include <glib-object.h>
-#include <gedit/gedit-plugin.h>
-
-G_BEGIN_DECLS
-
-/*
- * Type checking and casting macros
- */
-#define GEDIT_TYPE_TAGLIST_PLUGIN (gedit_taglist_plugin_get_type ())
-#define GEDIT_TAGLIST_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GEDIT_TYPE_TAGLIST_PLUGIN, GeditTaglistPlugin))
-#define GEDIT_TAGLIST_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GEDIT_TYPE_TAGLIST_PLUGIN, GeditTaglistPluginClass))
-#define GEDIT_IS_TAGLIST_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GEDIT_TYPE_TAGLIST_PLUGIN))
-#define GEDIT_IS_TAGLIST_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GEDIT_TYPE_TAGLIST_PLUGIN))
-#define GEDIT_TAGLIST_PLUGIN_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GEDIT_TYPE_TAGLIST_PLUGIN, GeditTaglistPluginClass))
-
-/* Private structure type */
-typedef struct _GeditTaglistPluginPrivate GeditTaglistPluginPrivate;
-
-/*
- * Main object structure
- */
-typedef struct _GeditTaglistPlugin GeditTaglistPlugin;
-
-struct _GeditTaglistPlugin
-{
- GeditPlugin parent_instance;
-
- /*< private >*/
- GeditTaglistPluginPrivate *priv;
-};
-
-/*
- * Class definition
- */
-typedef struct _GeditTaglistPluginClass GeditTaglistPluginClass;
-
-struct _GeditTaglistPluginClass
-{
- GeditPluginClass parent_class;
-};
-
-/*
- * Public methods
- */
-GType gedit_taglist_plugin_get_type (void) G_GNUC_CONST;
-
-/* All the plugins must implement this function */
-G_MODULE_EXPORT GType register_gedit_plugin (GTypeModule *module);
-
-G_END_DECLS
-
-#endif /* __GEDIT_TAGLIST_PLUGIN_H__ */
diff --git a/plugins/taglist/pluma-taglist-plugin-panel.h b/plugins/taglist/pluma-taglist-plugin-panel.h
new file mode 100755
index 00000000..cfeddfdd
--- /dev/null
+++ b/plugins/taglist/pluma-taglist-plugin-panel.h
@@ -0,0 +1,89 @@
+/*
+ * pluma-taglist-plugin-panel.h
+ * This file is part of pluma
+ *
+ * Copyright (C) 2005 - Paolo Maggi
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
+/*
+ * Modified by the pluma Team, 2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
+ * See the ChangeLog files for a list of changes.
+ *
+ * $Id$
+ */
+
+#ifndef __PLUMA_TAGLIST_PLUGIN_PANEL_H__
+#define __PLUMA_TAGLIST_PLUGIN_PANEL_H__
+
+#include <gtk/gtk.h>
+
+#include <pluma/pluma-window.h>
+
+G_BEGIN_DECLS
+
+/*
+ * Type checking and casting macros
+ */
+#define PLUMA_TYPE_TAGLIST_PLUGIN_PANEL (pluma_taglist_plugin_panel_get_type())
+#define PLUMA_TAGLIST_PLUGIN_PANEL(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL, PlumaTaglistPluginPanel))
+#define PLUMA_TAGLIST_PLUGIN_PANEL_CONST(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL, PlumaTaglistPluginPanel const))
+#define PLUMA_TAGLIST_PLUGIN_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL, PlumaTaglistPluginPanelClass))
+#define PLUMA_IS_TAGLIST_PLUGIN_PANEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL))
+#define PLUMA_IS_TAGLIST_PLUGIN_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL))
+#define PLUMA_TAGLIST_PLUGIN_PANEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), PLUMA_TYPE_TAGLIST_PLUGIN_PANEL, PlumaTaglistPluginPanelClass))
+
+/* Private structure type */
+typedef struct _PlumaTaglistPluginPanelPrivate PlumaTaglistPluginPanelPrivate;
+
+/*
+ * Main object structure
+ */
+typedef struct _PlumaTaglistPluginPanel PlumaTaglistPluginPanel;
+
+struct _PlumaTaglistPluginPanel
+{
+ GtkVBox vbox;
+
+ /*< private > */
+ PlumaTaglistPluginPanelPrivate *priv;
+};
+
+/*
+ * Class definition
+ */
+typedef struct _PlumaTaglistPluginPanelClass PlumaTaglistPluginPanelClass;
+
+struct _PlumaTaglistPluginPanelClass
+{
+ GtkVBoxClass parent_class;
+};
+
+/*
+ * Public methods
+ */
+GType pluma_taglist_plugin_panel_register_type (GTypeModule *module);
+
+GType pluma_taglist_plugin_panel_get_type (void) G_GNUC_CONST;
+
+GtkWidget *pluma_taglist_plugin_panel_new (PlumaWindow *window,
+ const gchar *data_dir);
+
+G_END_DECLS
+
+#endif /* __PLUMA_TAGLIST_PLUGIN_PANEL_H__ */
diff --git a/plugins/taglist/gedit-taglist-plugin-parser.h b/plugins/taglist/pluma-taglist-plugin-parser.h
index d008836e..42a8d3ff 100755
--- a/plugins/taglist/gedit-taglist-plugin-parser.h
+++ b/plugins/taglist/pluma-taglist-plugin-parser.h
@@ -1,6 +1,6 @@
/*
- * gedit-taglist-plugin-parser.h
- * This file is part of gedit
+ * pluma-taglist-plugin-parser.h
+ * This file is part of pluma
*
* Copyright (C) 2002-2005 - Paolo Maggi
*
@@ -21,15 +21,15 @@
*/
/*
- * Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
- * list of people on the gedit Team.
+ * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
* See the ChangeLog files for a list of changes.
*
* $Id$
*/
-#ifndef __GEDIT_TAGLIST_PLUGIN_PARSER_H__
-#define __GEDIT_TAGLIST_PLUGIN_PARSER_H__
+#ifndef __PLUMA_TAGLIST_PLUGIN_PARSER_H__
+#define __PLUMA_TAGLIST_PLUGIN_PARSER_H__
#include <libxml/tree.h>
#include <glib.h>
@@ -64,5 +64,5 @@ TagList* create_taglist (const gchar *data_dir);
void free_taglist (void);
-#endif /* __GEDIT_TAGLIST_PLUGIN_PARSER_H__ */
+#endif /* __PLUMA_TAGLIST_PLUGIN_PARSER_H__ */
diff --git a/plugins/taglist/pluma-taglist-plugin.h b/plugins/taglist/pluma-taglist-plugin.h
new file mode 100755
index 00000000..3ec8e088
--- /dev/null
+++ b/plugins/taglist/pluma-taglist-plugin.h
@@ -0,0 +1,85 @@
+/*
+ * pluma-taglist-plugin.h
+ *
+ * Copyright (C) 2002-2005 - Paolo Maggi
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ */
+
+/*
+ * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
+ * See the ChangeLog files for a list of changes.
+ *
+ * $Id$
+ */
+
+#ifndef __PLUMA_TAGLIST_PLUGIN_H__
+#define __PLUMA_TAGLIST_PLUGIN_H__
+
+#include <glib.h>
+#include <glib-object.h>
+#include <pluma/pluma-plugin.h>
+
+G_BEGIN_DECLS
+
+/*
+ * Type checking and casting macros
+ */
+#define PLUMA_TYPE_TAGLIST_PLUGIN (pluma_taglist_plugin_get_type ())
+#define PLUMA_TAGLIST_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), PLUMA_TYPE_TAGLIST_PLUGIN, PlumaTaglistPlugin))
+#define PLUMA_TAGLIST_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), PLUMA_TYPE_TAGLIST_PLUGIN, PlumaTaglistPluginClass))
+#define PLUMA_IS_TAGLIST_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), PLUMA_TYPE_TAGLIST_PLUGIN))
+#define PLUMA_IS_TAGLIST_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), PLUMA_TYPE_TAGLIST_PLUGIN))
+#define PLUMA_TAGLIST_PLUGIN_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), PLUMA_TYPE_TAGLIST_PLUGIN, PlumaTaglistPluginClass))
+
+/* Private structure type */
+typedef struct _PlumaTaglistPluginPrivate PlumaTaglistPluginPrivate;
+
+/*
+ * Main object structure
+ */
+typedef struct _PlumaTaglistPlugin PlumaTaglistPlugin;
+
+struct _PlumaTaglistPlugin
+{
+ PlumaPlugin parent_instance;
+
+ /*< private >*/
+ PlumaTaglistPluginPrivate *priv;
+};
+
+/*
+ * Class definition
+ */
+typedef struct _PlumaTaglistPluginClass PlumaTaglistPluginClass;
+
+struct _PlumaTaglistPluginClass
+{
+ PlumaPluginClass parent_class;
+};
+
+/*
+ * Public methods
+ */
+GType pluma_taglist_plugin_get_type (void) G_GNUC_CONST;
+
+/* All the plugins must implement this function */
+G_MODULE_EXPORT GType register_pluma_plugin (GTypeModule *module);
+
+G_END_DECLS
+
+#endif /* __PLUMA_TAGLIST_PLUGIN_H__ */
diff --git a/plugins/taglist/taglist.gedit-plugin.desktop.in b/plugins/taglist/taglist.pluma-plugin.desktop.in
index 09d0f2d0..7337358a 100755
--- a/plugins/taglist/taglist.gedit-plugin.desktop.in
+++ b/plugins/taglist/taglist.pluma-plugin.desktop.in
@@ -1,8 +1,8 @@
-[Gedit Plugin]
+[Pluma Plugin]
Module=taglist
IAge=2
_Name=Tag list
_Description=Provides a method to easily insert commonly used tags/strings into a document without having to type them.
Authors=Paolo Maggi <[email protected]>
Copyright=Copyright © 2002-2005 Paolo Maggi
-Website=http://www.gedit.org
+Website=http://www.pluma.org
diff --git a/plugins/taglist/gedit-taglist-plugin-panel.c b/plugins/taglist/pluma-taglist-plugin-panel.c
index d66acc08..513bf070 100755
--- a/plugins/taglist/gedit-taglist-plugin-panel.c
+++ b/plugins/taglist/pluma-taglist-plugin-panel.c
@@ -1,6 +1,6 @@
/*
* gedit-taglist-plugin-panel.c
* This file is part of gedit
*
* Copyright (C) 2005 - Paolo Maggi
*
@@ -21,8 +21,8 @@
*/
/*
* Modified by the gedit Team, 2005. See the AUTHORS file for a
* list of people on the gedit Team.
* See the ChangeLog files for a list of changes.
*
* $Id$
@@ -34,19 +34,19 @@
#include <string.h>
-#include "gedit-taglist-plugin-panel.h"
-#include "gedit-taglist-plugin-parser.h"
+#include "pluma-taglist-plugin-panel.h"
+#include "pluma-taglist-plugin-parser.h"
-#include <gedit/gedit-utils.h>
-#include <gedit/gedit-debug.h>
-#include <gedit/gedit-plugin.h>
+#include <pluma/pluma-utils.h>
+#include <pluma/pluma-debug.h>
+#include <pluma/pluma-plugin.h>
#include <gdk/gdkkeysyms.h>
#include <glib/gi18n.h>
-#define GEDIT_TAGLIST_PLUGIN_PANEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
- GEDIT_TYPE_TAGLIST_PLUGIN_PANEL, \
- GeditTaglistPluginPanelPrivate))
+#define PLUMA_TAGLIST_PLUGIN_PANEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+ PLUMA_TYPE_TAGLIST_PLUGIN_PANEL, \
+ PlumaTaglistPluginPanelPrivate))
enum
{
@@ -55,9 +55,9 @@ enum
NUM_COLUMNS
};
-struct _GeditTaglistPluginPanelPrivate
+struct _PlumaTaglistPluginPanelPrivate
{
- GeditWindow *window;
+ PlumaWindow *window;
GtkWidget *tag_groups_combo;
GtkWidget *tags_list;
@@ -68,7 +68,7 @@ struct _GeditTaglistPluginPanelPrivate
gchar *data_dir;
};
-GEDIT_PLUGIN_DEFINE_TYPE (GeditTaglistPluginPanel, gedit_taglist_plugin_panel, GTK_TYPE_VBOX)
+PLUMA_PLUGIN_DEFINE_TYPE (PlumaTaglistPluginPanel, pluma_taglist_plugin_panel, GTK_TYPE_VBOX)
enum
{
@@ -77,11 +77,11 @@ enum
};
static void
-set_window (GeditTaglistPluginPanel *panel,
- GeditWindow *window)
+set_window (PlumaTaglistPluginPanel *panel,
+ PlumaWindow *window)
{
g_return_if_fail (panel->priv->window == NULL);
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (PLUMA_IS_WINDOW (window));
panel->priv->window = window;
@@ -89,12 +89,12 @@ set_window (GeditTaglistPluginPanel *panel,
}
static void
-gedit_taglist_plugin_panel_set_property (GObject *object,
+pluma_taglist_plugin_panel_set_property (GObject *object,
guint prop_id,
const GValue *value,
GParamSpec *pspec)
{
- GeditTaglistPluginPanel *panel = GEDIT_TAGLIST_PLUGIN_PANEL (object);
+ PlumaTaglistPluginPanel *panel = PLUMA_TAGLIST_PLUGIN_PANEL (object);
switch (prop_id)
{
@@ -109,18 +109,18 @@ gedit_taglist_plugin_panel_set_property (GObject *object,
}
static void
-gedit_taglist_plugin_panel_get_property (GObject *object,
+pluma_taglist_plugin_panel_get_property (GObject *object,
guint prop_id,
GValue *value,
GParamSpec *pspec)
{
- GeditTaglistPluginPanel *panel = GEDIT_TAGLIST_PLUGIN_PANEL (object);
+ PlumaTaglistPluginPanel *panel = PLUMA_TAGLIST_PLUGIN_PANEL (object);
switch (prop_id)
{
case PROP_WINDOW:
g_value_set_object (value,
- GEDIT_TAGLIST_PLUGIN_PANEL_GET_PRIVATE (panel)->window);
+ PLUMA_TAGLIST_PLUGIN_PANEL_GET_PRIVATE (panel)->window);
break;
default:
G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -129,50 +129,50 @@ gedit_taglist_plugin_panel_get_property (GObject *object,
}
static void
-gedit_taglist_plugin_panel_finalize (GObject *object)
+pluma_taglist_plugin_panel_finalize (GObject *object)
{
- GeditTaglistPluginPanel *panel = GEDIT_TAGLIST_PLUGIN_PANEL (object);
+ PlumaTaglistPluginPanel *panel = PLUMA_TAGLIST_PLUGIN_PANEL (object);
g_free (panel->priv->data_dir);
- G_OBJECT_CLASS (gedit_taglist_plugin_panel_parent_class)->finalize (object);
+ G_OBJECT_CLASS (pluma_taglist_plugin_panel_parent_class)->finalize (object);
}
static void
-gedit_taglist_plugin_panel_class_init (GeditTaglistPluginPanelClass *klass)
+pluma_taglist_plugin_panel_class_init (PlumaTaglistPluginPanelClass *klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
- object_class->finalize = gedit_taglist_plugin_panel_finalize;
- object_class->get_property = gedit_taglist_plugin_panel_get_property;
- object_class->set_property = gedit_taglist_plugin_panel_set_property;
+ object_class->finalize = pluma_taglist_plugin_panel_finalize;
+ object_class->get_property = pluma_taglist_plugin_panel_get_property;
+ object_class->set_property = pluma_taglist_plugin_panel_set_property;
g_object_class_install_property (object_class,
PROP_WINDOW,
g_param_spec_object ("window",
"Window",
- "The GeditWindow this GeditTaglistPluginPanel is associated with",
- GEDIT_TYPE_WINDOW,
+ "The PlumaWindow this PlumaTaglistPluginPanel is associated with",
+ PLUMA_TYPE_WINDOW,
G_PARAM_READWRITE |
G_PARAM_CONSTRUCT_ONLY));
- g_type_class_add_private (object_class, sizeof(GeditTaglistPluginPanelPrivate));
+ g_type_class_add_private (object_class, sizeof(PlumaTaglistPluginPanelPrivate));
}
static void
-insert_tag (GeditTaglistPluginPanel *panel,
+insert_tag (PlumaTaglistPluginPanel *panel,
Tag *tag,
gboolean grab_focus)
{
- GeditView *view;
+ PlumaView *view;
GtkTextBuffer *buffer;
GtkTextIter start, end;
GtkTextIter cursor;
gboolean sel = FALSE;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
- view = gedit_window_get_active_view (panel->priv->window);
+ view = pluma_window_get_active_view (panel->priv->window);
g_return_if_fail (view != NULL);
buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -242,13 +242,13 @@ static void
tag_list_row_activated_cb (GtkTreeView *tag_list,
GtkTreePath *path,
GtkTreeViewColumn *column,
- GeditTaglistPluginPanel *panel)
+ PlumaTaglistPluginPanel *panel)
{
GtkTreeIter iter;
GtkTreeModel *model;
gint index;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
model = gtk_tree_view_get_model (tag_list);
@@ -257,7 +257,7 @@ tag_list_row_activated_cb (GtkTreeView *tag_list,
gtk_tree_model_get (model, &iter, COLUMN_TAG_INDEX_IN_GROUP, &index, -1);
- gedit_debug_message (DEBUG_PLUGINS, "Index: %d", index);
+ pluma_debug_message (DEBUG_PLUGINS, "Index: %d", index);
insert_tag (panel,
(Tag*)g_list_nth_data (panel->priv->selected_tag_group->tags, index),
@@ -267,7 +267,7 @@ tag_list_row_activated_cb (GtkTreeView *tag_list,
static gboolean
tag_list_key_press_event_cb (GtkTreeView *tag_list,
GdkEventKey *event,
- GeditTaglistPluginPanel *panel)
+ PlumaTaglistPluginPanel *panel)
{
gboolean grab_focus;
@@ -280,7 +280,7 @@ tag_list_key_press_event_cb (GtkTreeView *tag_list,
GtkTreeIter iter;
gint index;
- gedit_debug_message (DEBUG_PLUGINS, "RETURN Pressed");
+ pluma_debug_message (DEBUG_PLUGINS, "RETURN Pressed");
model = gtk_tree_view_get_model (tag_list);
@@ -290,7 +290,7 @@ tag_list_key_press_event_cb (GtkTreeView *tag_list,
{
gtk_tree_model_get (model, &iter, COLUMN_TAG_INDEX_IN_GROUP, &index, -1);
- gedit_debug_message (DEBUG_PLUGINS, "Index: %d", index);
+ pluma_debug_message (DEBUG_PLUGINS, "Index: %d", index);
insert_tag (panel,
(Tag*)g_list_nth_data (panel->priv->selected_tag_group->tags, index),
@@ -304,14 +304,14 @@ tag_list_key_press_event_cb (GtkTreeView *tag_list,
}
static GtkTreeModel*
-create_model (GeditTaglistPluginPanel *panel)
+create_model (PlumaTaglistPluginPanel *panel)
{
gint i = 0;
GtkListStore *store;
GtkTreeIter iter;
GList *list;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
/* create list store */
store = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_INT);
@@ -325,7 +325,7 @@ create_model (GeditTaglistPluginPanel *panel)
tag_name = (gchar *)((Tag*)list->data)->name;
- gedit_debug_message (DEBUG_PLUGINS, "%d : %s", i, tag_name);
+ pluma_debug_message (DEBUG_PLUGINS, "%d : %s", i, tag_name);
gtk_list_store_append (store, &iter);
gtk_list_store_set (store, &iter,
@@ -337,18 +337,18 @@ create_model (GeditTaglistPluginPanel *panel)
list = g_list_next (list);
}
- gedit_debug_message (DEBUG_PLUGINS, "Rows: %d ",
+ pluma_debug_message (DEBUG_PLUGINS, "Rows: %d ",
gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL));
return GTK_TREE_MODEL (store);
}
static void
-populate_tags_list (GeditTaglistPluginPanel *panel)
+populate_tags_list (PlumaTaglistPluginPanel *panel)
{
GtkTreeModel* model;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
g_return_if_fail (taglist != NULL);
@@ -363,7 +363,7 @@ find_tag_group (const gchar *name)
{
GList *l;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
g_return_val_if_fail (taglist != NULL, NULL);
@@ -377,12 +377,12 @@ find_tag_group (const gchar *name)
}
static void
-populate_tag_groups_combo (GeditTaglistPluginPanel *panel)
+populate_tag_groups_combo (PlumaTaglistPluginPanel *panel)
{
GList *l;
GtkComboBox *combo;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
combo = GTK_COMBO_BOX (panel->priv->tag_groups_combo);
@@ -402,11 +402,11 @@ populate_tag_groups_combo (GeditTaglistPluginPanel *panel)
static void
selected_group_changed (GtkComboBox *combo,
- GeditTaglistPluginPanel *panel)
+ PlumaTaglistPluginPanel *panel)
{
gchar* group_name;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
group_name = gtk_combo_box_get_active_text (combo);
@@ -422,7 +422,7 @@ selected_group_changed (GtkComboBox *combo,
panel->priv->selected_tag_group = find_tag_group (group_name);
g_return_if_fail (panel->priv->selected_tag_group != NULL);
- gedit_debug_message (DEBUG_PLUGINS,
+ pluma_debug_message (DEBUG_PLUGINS,
"New selected group: %s",
panel->priv->selected_tag_group->name);
@@ -467,7 +467,7 @@ create_preview_string (Tag *tag)
}
static void
-update_preview (GeditTaglistPluginPanel *panel,
+update_preview (PlumaTaglistPluginPanel *panel,
Tag *tag)
{
gchar *str;
@@ -489,7 +489,7 @@ tag_list_cursor_changed_cb (GtkTreeView *tag_list,
GtkTreeIter iter;
gint index;
- GeditTaglistPluginPanel *panel = (GeditTaglistPluginPanel *)data;
+ PlumaTaglistPluginPanel *panel = (PlumaTaglistPluginPanel *)data;
model = gtk_tree_view_get_model (tag_list);
@@ -499,7 +499,7 @@ tag_list_cursor_changed_cb (GtkTreeView *tag_list,
{
gtk_tree_model_get (model, &iter, COLUMN_TAG_INDEX_IN_GROUP, &index, -1);
- gedit_debug_message (DEBUG_PLUGINS, "Index: %d", index);
+ pluma_debug_message (DEBUG_PLUGINS, "Index: %d", index);
update_preview (panel,
(Tag*)g_list_nth_data (panel->priv->selected_tag_group->tags, index));
@@ -512,7 +512,7 @@ tags_list_query_tooltip_cb (GtkWidget *widget,
gint y,
gboolean keyboard_tip,
GtkTooltip *tooltip,
- GeditTaglistPluginPanel *panel)
+ PlumaTaglistPluginPanel *panel)
{
GtkTreeIter iter;
GtkTreeModel *model;
@@ -578,16 +578,16 @@ expose_event_cb (GtkWidget *panel,
GdkEventExpose *event,
gpointer user_data)
{
- GeditTaglistPluginPanel *ppanel = GEDIT_TAGLIST_PLUGIN_PANEL (panel);
+ PlumaTaglistPluginPanel *ppanel = PLUMA_TAGLIST_PLUGIN_PANEL (panel);
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
/* If needed load taglists from files at the first expose */
if (taglist == NULL)
create_taglist (ppanel->priv->data_dir);
/* And populate combo box */
- populate_tag_groups_combo (GEDIT_TAGLIST_PLUGIN_PANEL (panel));
+ populate_tag_groups_combo (PLUMA_TAGLIST_PLUGIN_PANEL (panel));
/* We need to manage only the first expose event -> disconnect */
g_signal_handlers_disconnect_by_func (panel, expose_event_cb, NULL);
@@ -616,7 +616,7 @@ realize_tag_groups_combo (GtkWidget *combo,
}
static void
-add_preview_widget (GeditTaglistPluginPanel *panel)
+add_preview_widget (PlumaTaglistPluginPanel *panel)
{
GtkWidget *expander;
GtkWidget *frame;
@@ -650,16 +650,16 @@ add_preview_widget (GeditTaglistPluginPanel *panel)
}
static void
-gedit_taglist_plugin_panel_init (GeditTaglistPluginPanel *panel)
+pluma_taglist_plugin_panel_init (PlumaTaglistPluginPanel *panel)
{
GtkWidget *sw;
GtkTreeViewColumn *column;
GtkCellRenderer *cell;
GList *focus_chain = NULL;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
- panel->priv = GEDIT_TAGLIST_PLUGIN_PANEL_GET_PRIVATE (panel);
+ panel->priv = PLUMA_TAGLIST_PLUGIN_PANEL_GET_PRIVATE (panel);
panel->priv->data_dir = NULL;
/* Build the window content */
@@ -687,16 +687,16 @@ gedit_taglist_plugin_panel_init (GeditTaglistPluginPanel *panel)
/* Create tree view */
panel->priv->tags_list = gtk_tree_view_new ();
- gedit_utils_set_atk_name_description (panel->priv->tag_groups_combo,
+ pluma_utils_set_atk_name_description (panel->priv->tag_groups_combo,
_("Available Tag Lists"),
NULL);
- gedit_utils_set_atk_name_description (panel->priv->tags_list,
+ pluma_utils_set_atk_name_description (panel->priv->tags_list,
_("Tags"),
NULL);
- gedit_utils_set_atk_relation (panel->priv->tag_groups_combo,
+ pluma_utils_set_atk_relation (panel->priv->tag_groups_combo,
panel->priv->tags_list,
ATK_RELATION_CONTROLLER_FOR);
- gedit_utils_set_atk_relation (panel->priv->tags_list,
+ pluma_utils_set_atk_relation (panel->priv->tags_list,
panel->priv->tag_groups_combo,
ATK_RELATION_CONTROLLED_BY);
@@ -759,14 +759,14 @@ gedit_taglist_plugin_panel_init (GeditTaglistPluginPanel *panel)
}
GtkWidget *
-gedit_taglist_plugin_panel_new (GeditWindow *window,
+pluma_taglist_plugin_panel_new (PlumaWindow *window,
const gchar *data_dir)
{
- GeditTaglistPluginPanel *panel;
+ PlumaTaglistPluginPanel *panel;
- g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
+ g_return_val_if_fail (PLUMA_IS_WINDOW (window), NULL);
- panel = g_object_new (GEDIT_TYPE_TAGLIST_PLUGIN_PANEL,
+ panel = g_object_new (PLUMA_TYPE_TAGLIST_PLUGIN_PANEL,
"window", window,
NULL);
@@ -1,6 +1,6 @@
/*
- * gedit-taglist-plugin-panel.c
- * This file is part of gedit
+ * pluma-taglist-plugin-panel.c
+ * This file is part of pluma
*
* Copyright (C) 2005 - Paolo Maggi
@@ -21,8 +21,8 @@
*/
/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
+ * Modified by the pluma Team, 2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
* See the ChangeLog files for a list of changes.
*
diff --git a/plugins/taglist/gedit-taglist-plugin-parser.c b/plugins/taglist/pluma-taglist-plugin-parser.c
index e09c0e25..bc7767d0 100755
--- a/plugins/taglist/gedit-taglist-plugin-parser.c
+++ b/plugins/taglist/pluma-taglist-plugin-parser.c
@@ -1,6 +1,6 @@
/*
* gedit-taglist-plugin-parser.c
* This file is part of gedit
*
* Copyright (C) 2002-2005 - Paolo Maggi
*
@@ -21,8 +21,8 @@
*/
/*
* Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
* list of people on the gedit Team.
* See the ChangeLog files for a list of changes.
*
* $Id$
@@ -39,13 +39,13 @@
#include <glib.h>
#include <glib/gi18n.h>
-#include <gedit/gedit-debug.h>
+#include <pluma/pluma-debug.h>
-#include "gedit-taglist-plugin-parser.h"
+#include "pluma-taglist-plugin-parser.h"
/* we screwed up so we still look here for compatibility */
-#define USER_GEDIT_TAGLIST_PLUGIN_LOCATION_LEGACY ".gedit-2/plugins/taglist/"
-#define USER_GEDIT_TAGLIST_PLUGIN_LOCATION "gedit/taglist/"
+#define USER_PLUMA_TAGLIST_PLUGIN_LOCATION_LEGACY ".pluma-2/plugins/taglist/"
+#define USER_PLUMA_TAGLIST_PLUGIN_LOCATION "pluma/taglist/"
TagList *taglist = NULL;
static gint taglist_ref_count = 0;
@@ -68,7 +68,7 @@ static gboolean
parse_tag (Tag *tag, xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur)
{
/*
- gedit_debug_message (DEBUG_PLUGINS, " Tag name: %s", tag->name);
+ pluma_debug_message (DEBUG_PLUGINS, " Tag name: %s", tag->name);
*/
/* We don't care what the top level element name is */
cur = cur->xmlChildrenNode;
@@ -80,7 +80,7 @@ parse_tag (Tag *tag, xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur)
{
tag->begin = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
/*
- gedit_debug_message (DEBUG_PLUGINS, " - Begin: %s", tag->begin);
+ pluma_debug_message (DEBUG_PLUGINS, " - Begin: %s", tag->begin);
*/
}
@@ -89,7 +89,7 @@ parse_tag (Tag *tag, xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur)
{
tag->end = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
/*
- gedit_debug_message (DEBUG_PLUGINS, " - End: %s", tag->end);
+ pluma_debug_message (DEBUG_PLUGINS, " - End: %s", tag->end);
*/
}
@@ -115,7 +115,7 @@ static gboolean
parse_tag_group (TagGroup *tg, const gchar* fn, xmlDocPtr doc,
xmlNsPtr ns, xmlNodePtr cur, gboolean sort)
{
- gedit_debug_message (DEBUG_PLUGINS, "Parse TagGroup: %s", tg->name);
+ pluma_debug_message (DEBUG_PLUGINS, "Parse TagGroup: %s", tg->name);
/* We don't care what the top level element name is */
cur = cur->xmlChildrenNode;
@@ -227,7 +227,7 @@ get_tag_group (const gchar* filename, xmlDocPtr doc,
if (strcmp (tgn, (gchar*)tag_group->name) == 0)
{
- gedit_debug_message (DEBUG_PLUGINS,
+ pluma_debug_message (DEBUG_PLUGINS,
"Tag group '%s' already exists.", tgn);
exists = TRUE;
@@ -271,15 +271,15 @@ groups_cmp (gconstpointer a, gconstpointer b)
/*
* tags file is localized by intltool-merge below.
*
- * <gedit:TagGroup name="XSLT - Elements">
- * </gedit:TagGroup>
- * <gedit:TagGroup xml:lang="am" name="LOCALIZED TEXT">
- * </gedit:TagGroup>
- * <gedit:TagGroup xml:lang="ar" name="LOCALIZED TEXT">
- * </gedit:TagGroup>
+ * <pluma:TagGroup name="XSLT - Elements">
+ * </pluma:TagGroup>
+ * <pluma:TagGroup xml:lang="am" name="LOCALIZED TEXT">
+ * </pluma:TagGroup>
+ * <pluma:TagGroup xml:lang="ar" name="LOCALIZED TEXT">
+ * </pluma:TagGroup>
* .....
- * <gedit:TagGroup name="XSLT - Functions">
- * </gedit:TagGroup>
+ * <pluma:TagGroup name="XSLT - Functions">
+ * </pluma:TagGroup>
* .....
* Therefore need to pick up the best lang on the current locale.
*/
@@ -419,7 +419,7 @@ parse_taglist_file (const gchar* filename)
xmlNsPtr ns;
xmlNodePtr cur;
- gedit_debug_message (DEBUG_PLUGINS, "Parse file: %s", filename);
+ pluma_debug_message (DEBUG_PLUGINS, "Parse file: %s", filename);
xmlKeepBlanksDefault (0);
@@ -448,12 +448,12 @@ parse_taglist_file (const gchar* filename)
}
ns = xmlSearchNsByHref (doc, cur,
- (const xmlChar *) "http://gedit.sourceforge.net/some-location");
+ (const xmlChar *) "http://pluma.sourceforge.net/some-location");
if (ns == NULL)
{
g_warning ("The tag list file '%s' is of the wrong type, "
- "gedit namespace not found.", filename);
+ "pluma namespace not found.", filename);
xmlFreeDoc (doc);
return taglist;
@@ -479,7 +479,7 @@ parse_taglist_file (const gchar* filename)
xmlFreeDoc (doc);
- gedit_debug_message (DEBUG_PLUGINS, "END");
+ pluma_debug_message (DEBUG_PLUGINS, "END");
return taglist;
}
@@ -488,7 +488,7 @@ static void
free_tag (Tag *tag)
{
/*
- gedit_debug_message (DEBUG_PLUGINS, "Tag: %s", tag->name);
+ pluma_debug_message (DEBUG_PLUGINS, "Tag: %s", tag->name);
*/
g_return_if_fail (tag != NULL);
@@ -508,7 +508,7 @@ free_tag_group (TagGroup *tag_group)
{
GList *l;
- gedit_debug_message (DEBUG_PLUGINS, "Tag group: %s", tag_group->name);
+ pluma_debug_message (DEBUG_PLUGINS, "Tag group: %s", tag_group->name);
g_return_if_fail (tag_group != NULL);
@@ -522,7 +522,7 @@ free_tag_group (TagGroup *tag_group)
g_list_free (tag_group->tags);
g_free (tag_group);
- gedit_debug_message (DEBUG_PLUGINS, "END");
+ pluma_debug_message (DEBUG_PLUGINS, "END");
}
void
@@ -530,7 +530,7 @@ free_taglist (void)
{
GList *l;
- gedit_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
+ pluma_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
if (taglist == NULL)
return;
@@ -550,7 +550,7 @@ free_taglist (void)
g_free (taglist);
taglist = NULL;
- gedit_debug_message (DEBUG_PLUGINS, "Really freed");
+ pluma_debug_message (DEBUG_PLUGINS, "Really freed");
}
static TagList *
@@ -560,12 +560,12 @@ parse_taglist_dir (const gchar *dir)
GDir *d;
const gchar *dirent;
- gedit_debug_message (DEBUG_PLUGINS, "DIR: %s", dir);
+ pluma_debug_message (DEBUG_PLUGINS, "DIR: %s", dir);
d = g_dir_open (dir, 0, &error);
if (!d)
{
- gedit_debug_message (DEBUG_PLUGINS, "%s", error->message);
+ pluma_debug_message (DEBUG_PLUGINS, "%s", error->message);
g_error_free (error);
return taglist;
}
@@ -590,7 +590,7 @@ TagList* create_taglist (const gchar *data_dir)
{
gchar *pdir;
- gedit_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
+ pluma_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
if (taglist_ref_count > 0)
{
@@ -610,7 +610,7 @@ TagList* create_taglist (const gchar *data_dir)
if (home != NULL)
{
pdir = g_build_filename (home,
- USER_GEDIT_TAGLIST_PLUGIN_LOCATION_LEGACY,
+ USER_PLUMA_TAGLIST_PLUGIN_LOCATION_LEGACY,
NULL);
parse_taglist_dir (pdir);
g_free (pdir);
@@ -621,7 +621,7 @@ TagList* create_taglist (const gchar *data_dir)
if (envvar != NULL)
{
pdir = g_build_filename (envvar,
- USER_GEDIT_TAGLIST_PLUGIN_LOCATION,
+ USER_PLUMA_TAGLIST_PLUGIN_LOCATION,
NULL);
parse_taglist_dir (pdir);
g_free (pdir);
@@ -630,7 +630,7 @@ TagList* create_taglist (const gchar *data_dir)
{
pdir = g_build_filename (home,
".mate2",
- USER_GEDIT_TAGLIST_PLUGIN_LOCATION,
+ USER_PLUMA_TAGLIST_PLUGIN_LOCATION,
NULL);
parse_taglist_dir (pdir);
g_free (pdir);
@@ -638,7 +638,7 @@ TagList* create_taglist (const gchar *data_dir)
#else
pdir = g_build_filename (g_get_user_config_dir (),
- "gedit",
+ "pluma",
"taglist",
NULL);
parse_taglist_dir (pdir);
@@ -1,6 +1,6 @@
/*
- * gedit-taglist-plugin-parser.c
- * This file is part of gedit
+ * pluma-taglist-plugin-parser.c
+ * This file is part of pluma
*
* Copyright (C) 2002-2005 - Paolo Maggi
@@ -21,8 +21,8 @@
*/
/*
- * Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
- * list of people on the gedit Team.
+ * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
* See the ChangeLog files for a list of changes.
*
diff --git a/plugins/taglist/gedit-taglist-plugin.c b/plugins/taglist/pluma-taglist-plugin.c
index 081fefcb..202ab12e 100755
--- a/plugins/taglist/gedit-taglist-plugin.c
+++ b/plugins/taglist/pluma-taglist-plugin.c
@@ -1,5 +1,5 @@
/*
- * gedit-taglist-plugin.h
+ * pluma-taglist-plugin.h
*
* Copyright (C) 2002-2005 - Paolo Maggi
*
@@ -20,8 +20,8 @@
*/
/*
* Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
* list of people on the gedit Team.
* See the ChangeLog files for a list of changes.
*
* $Id$
@@ -31,69 +31,69 @@
#include <config.h>
#endif
-#include "gedit-taglist-plugin.h"
-#include "gedit-taglist-plugin-panel.h"
-#include "gedit-taglist-plugin-parser.h"
+#include "pluma-taglist-plugin.h"
+#include "pluma-taglist-plugin-panel.h"
+#include "pluma-taglist-plugin-parser.h"
#include <glib/gi18n-lib.h>
#include <gmodule.h>
-#include <gedit/gedit-plugin.h>
-#include <gedit/gedit-debug.h>
+#include <pluma/pluma-plugin.h>
+#include <pluma/pluma-debug.h>
-#define WINDOW_DATA_KEY "GeditTaglistPluginWindowData"
+#define WINDOW_DATA_KEY "PlumaTaglistPluginWindowData"
-#define GEDIT_TAGLIST_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_TAGLIST_PLUGIN, GeditTaglistPluginPrivate))
+#define PLUMA_TAGLIST_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PLUMA_TYPE_TAGLIST_PLUGIN, PlumaTaglistPluginPrivate))
-struct _GeditTaglistPluginPrivate
+struct _PlumaTaglistPluginPrivate
{
gpointer dummy;
};
-GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE (GeditTaglistPlugin, gedit_taglist_plugin,
- gedit_taglist_plugin_panel_register_type (module);
+PLUMA_PLUGIN_REGISTER_TYPE_WITH_CODE (PlumaTaglistPlugin, pluma_taglist_plugin,
+ pluma_taglist_plugin_panel_register_type (module);
)
static void
-gedit_taglist_plugin_init (GeditTaglistPlugin *plugin)
+pluma_taglist_plugin_init (PlumaTaglistPlugin *plugin)
{
- plugin->priv = GEDIT_TAGLIST_PLUGIN_GET_PRIVATE (plugin);
+ plugin->priv = PLUMA_TAGLIST_PLUGIN_GET_PRIVATE (plugin);
- gedit_debug_message (DEBUG_PLUGINS, "GeditTaglistPlugin initializing");
+ pluma_debug_message (DEBUG_PLUGINS, "PlumaTaglistPlugin initializing");
}
static void
-gedit_taglist_plugin_finalize (GObject *object)
+pluma_taglist_plugin_finalize (GObject *object)
{
/*
- GeditTaglistPlugin *plugin = GEDIT_TAGLIST_PLUGIN (object);
+ PlumaTaglistPlugin *plugin = PLUMA_TAGLIST_PLUGIN (object);
*/
- gedit_debug_message (DEBUG_PLUGINS, "GeditTaglistPlugin finalizing");
+ pluma_debug_message (DEBUG_PLUGINS, "PlumaTaglistPlugin finalizing");
free_taglist ();
- G_OBJECT_CLASS (gedit_taglist_plugin_parent_class)->finalize (object);
+ G_OBJECT_CLASS (pluma_taglist_plugin_parent_class)->finalize (object);
}
static void
-impl_activate (GeditPlugin *plugin,
- GeditWindow *window)
+impl_activate (PlumaPlugin *plugin,
+ PlumaWindow *window)
{
- GeditPanel *side_panel;
+ PlumaPanel *side_panel;
GtkWidget *taglist_panel;
gchar *data_dir;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
g_return_if_fail (g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY) == NULL);
- side_panel = gedit_window_get_side_panel (window);
+ side_panel = pluma_window_get_side_panel (window);
- data_dir = gedit_plugin_get_data_dir (plugin);
- taglist_panel = gedit_taglist_plugin_panel_new (window, data_dir);
+ data_dir = pluma_plugin_get_data_dir (plugin);
+ taglist_panel = pluma_taglist_plugin_panel_new (window, data_dir);
g_free (data_dir);
- gedit_panel_add_item_with_stock_icon (side_panel,
+ pluma_panel_add_item_with_stock_icon (side_panel,
taglist_panel,
_("Tags"),
GTK_STOCK_ADD);
@@ -104,20 +104,20 @@ impl_activate (GeditPlugin *plugin,
}
static void
-impl_deactivate (GeditPlugin *plugin,
- GeditWindow *window)
+impl_deactivate (PlumaPlugin *plugin,
+ PlumaWindow *window)
{
- GeditPanel *side_panel;
+ PlumaPanel *side_panel;
gpointer data;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
g_return_if_fail (data != NULL);
- side_panel = gedit_window_get_side_panel (window);
+ side_panel = pluma_window_get_side_panel (window);
- gedit_panel_remove_item (side_panel,
+ pluma_panel_remove_item (side_panel,
GTK_WIDGET (data));
g_object_set_data (G_OBJECT (window),
@@ -126,18 +126,18 @@ impl_deactivate (GeditPlugin *plugin,
}
static void
-impl_update_ui (GeditPlugin *plugin,
- GeditWindow *window)
+impl_update_ui (PlumaPlugin *plugin,
+ PlumaWindow *window)
{
gpointer data;
- GeditView *view;
+ PlumaView *view;
- gedit_debug (DEBUG_PLUGINS);
+ pluma_debug (DEBUG_PLUGINS);
data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
g_return_if_fail (data != NULL);
- view = gedit_window_get_active_view (window);
+ view = pluma_window_get_active_view (window);
gtk_widget_set_sensitive (GTK_WIDGET (data),
(view != NULL) &&
@@ -145,16 +145,16 @@ impl_update_ui (GeditPlugin *plugin,
}
static void
-gedit_taglist_plugin_class_init (GeditTaglistPluginClass *klass)
+pluma_taglist_plugin_class_init (PlumaTaglistPluginClass *klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
- GeditPluginClass *plugin_class = GEDIT_PLUGIN_CLASS (klass);
+ PlumaPluginClass *plugin_class = PLUMA_PLUGIN_CLASS (klass);
- object_class->finalize = gedit_taglist_plugin_finalize;
+ object_class->finalize = pluma_taglist_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
plugin_class->update_ui = impl_update_ui;
- g_type_class_add_private (object_class, sizeof (GeditTaglistPluginPrivate));
+ g_type_class_add_private (object_class, sizeof (PlumaTaglistPluginPrivate));
}
@@ -20,8 +20,8 @@
*/
/*
- * Modified by the gedit Team, 2002-2005. See the AUTHORS file for a
- * list of people on the gedit Team.
+ * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
* See the ChangeLog files for a list of changes.
*